@@ -45,6 +45,7 @@ setMethod( "dtiTensor", "dtiData",
              mc.cores <- min(mc.cores,detectCores())
              args <- sys.call(-1)
              args <- c(object@call,args)
+             if(!is.null(attributes(object)$ns0)) object <- expanddwiobj(object)
              ngrad <- object@ngrad
              grad <- object@gradient
              btb <- object@btb
@@ -54,6 +55,8 @@ setMethod( "dtiTensor", "dtiData",
              ns0 <- length(s0ind)
              sdcoef <- object@sdcoef
              ngrad0 <- ngrad-ns0
+             if(is.null(mask)) mask <- object@mask
+# prefer mask from object over mask defined by level
              z <- sioutlier1(object@si,s0ind,object@level,mask,mc.cores=mc.cores)
              #
              #  this does not scale well with openMP
