@@ -4,7 +4,10 @@
 #                                                              #
 ################################################################
 
-dtiData <- function(gradient,imagefile,ddim,bvalue=NULL,xind=NULL,yind=NULL,zind=NULL,level=0,mins0value=1,maxvalue=32000,voxelext=c(1,1,1),orientation=c(0L,2L,5L),rotation=diag(3)) {
+dtiData <- function(gradient,imagefile,ddim,bvalue=NULL,xind=NULL,
+                    yind=NULL,zind=NULL,level=0,mins0value=1,
+                    maxvalue=32000,voxelext=c(1,1,1),
+                    orientation=c(0L,2L,5L),rotation=diag(3)) {
   args <- list(sys.call())
   if (any(sort((orientation)%/%2) != 0:2)) stop("invalid orientation \n")
   if (dim(gradient)[2]==3) gradient <- t(gradient)
@@ -411,8 +414,6 @@ readDWIdata <- function(gradient, dirlist,
 setMethod("print", "dtiData",
           function(x){
             cat("  Object of class", class(x),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -425,8 +426,6 @@ setMethod("print", "dtiData",
 setMethod("print", "dtiTensor",
           function(x){
             cat("  Object of class", class(x),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -440,8 +439,6 @@ setMethod("print", "dtiTensor",
 setMethod( "print", "dkiTensor",
            function( x) {
              cat( "  Object of class", class(x), "\n")
-#             cat( "  Generated by calls   :\n")
-#             print( x@call)
              cat( "  Dimension            :", paste( x@ddim, collapse = "x"), "\n")
              ns0 <- length( x@s0ind)
              cat( "  Number of S0 images  :", paste( ns0, collapse = "x"), "\n")
@@ -455,8 +452,6 @@ setMethod( "print", "dkiTensor",
 setMethod("print", "dwiMixtensor",
           function(x){
             cat("  Object of class", class(x),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -470,8 +465,6 @@ setMethod("print", "dwiMixtensor",
 setMethod("print", "dwiQball",
           function(x){
             cat("  Object of class", class(x),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -486,8 +479,6 @@ setMethod("print", "dwiQball",
 setMethod("print","dtiIndices",
           function(x){
             cat("  Object of class", class(x),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -501,8 +492,6 @@ setMethod("print","dtiIndices",
 setMethod("print","dkiIndices",
           function(x){
             cat("  Object of class", class(x),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -516,8 +505,6 @@ setMethod("print","dkiIndices",
 setMethod("print","dwiFiber",
           function(x){
             cat("  Object of class", class(x),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(x@call)
             cat("  Dimension            :", paste(x@ddim, collapse="x"), "\n")
             ns0 <- length(x@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -533,8 +520,6 @@ setMethod("print","dwiFiber",
 setMethod("show", "dtiData",
           function(object){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -547,8 +532,6 @@ setMethod("show", "dtiData",
 setMethod("show", "dtiTensor",
           function(object){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -562,8 +545,6 @@ setMethod("show", "dtiTensor",
 setMethod( "show", "dkiTensor",
            function( object) {
              cat( "  Object of class", class( object), "\n")
-#             cat( "  Generated by calls   :\n")
-#             print( object@call)
              cat( "  Dimension            :", paste( object@ddim, collapse = "x"), "\n")
              ns0 <- length( object@s0ind)
              cat( "  Number of S0 images  :", paste( ns0, collapse = "x"), "\n")
@@ -577,8 +558,6 @@ setMethod( "show", "dkiTensor",
 setMethod("show", "dwiMixtensor",
           function(object){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -592,8 +571,6 @@ setMethod("show", "dwiMixtensor",
 setMethod("show", "dtiIndices",
           function(object){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -607,8 +584,6 @@ setMethod("show", "dtiIndices",
 setMethod("show", "dkiIndices",
           function(object){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -622,8 +597,6 @@ setMethod("show", "dkiIndices",
 setMethod("show","dwiFiber",
           function(object){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls   :\n")
-#            print(object@call)
             cat("  Dimension            :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images  :", paste(ns0, collapse="x"), "\n")
@@ -639,9 +612,6 @@ setMethod("show","dwiFiber",
 setMethod("summary", "dtiData",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls    :\n")
-#            print(object@call)
-#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
@@ -651,16 +621,17 @@ setMethod("summary", "dtiData",
             cat("  Quantiles of S0-values:","\n")
             print(signif(quantile(object@si[,,,object@s0ind],...),3))
             cat("  Mean S0-value         :", signif(mean(object@si[,,,object@s0ind]),3), "\n")
-            cat("  Threshold for mask    :", paste(signif(object@level,3),collapse="x"), "\n")
+            if(!is.null(object@mask)){
+               cat("  Voxel in mask         :", paste(sum(object@mask), collapse="x"), "\n")
+            } else {
+               cat("  Threshold for mask    :", paste(signif(object@level,3),collapse="x"), "\n")
+            }
             cat("\n")
             invisible(NULL)
           })
 setMethod("summary", "dtiTensor",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls    :\n")
-#            print(object@call)
-#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ngrad <- object@ngrad
             ns0 <- length(object@s0ind)
@@ -684,9 +655,6 @@ setMethod("summary", "dtiTensor",
 setMethod( "summary", "dkiTensor",
            function( object, ...) {
              cat( "  Object of class", class( object), "\n")
-#             cat( "  Generated by calls    :\n")
-#             print( object@call)
-#             cat( "  Source-Filename       :", object@source, "\n")
              cat( "  Dimension             :", paste( object@ddim, collapse = "x"), "\n")
              ngrad <- object@ngrad
              ns0 <- length( object@s0ind)
@@ -710,9 +678,6 @@ setMethod( "summary", "dkiTensor",
 setMethod("summary", "dwiMixtensor",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls    :\n")
-#            print(object@call)
-#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ngrad <- object@ngrad
             ns0 <- length(object@s0ind)
@@ -738,9 +703,6 @@ setMethod("summary", "dwiMixtensor",
 setMethod("summary", "dwiQball",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls    :\n")
-#            print(object@call)
-#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
@@ -765,9 +727,6 @@ setMethod("summary", "dwiQball",
 setMethod("summary", "dtiIndices",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls    :\n")
-#            print(object@call)
-#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
@@ -787,9 +746,6 @@ setMethod("summary", "dtiIndices",
 setMethod("summary", "dkiIndices",
           function(object, ...){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls    :\n")
-#            print(object@call)
-#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
@@ -809,9 +765,6 @@ setMethod("summary", "dkiIndices",
 setMethod("summary","dwiFiber",
           function(object){
             cat("  Object of class", class(object),"\n")
-#            cat("  Generated by calls    :\n")
-#            print(object@call)
-#            cat("  Source-Filename       :", object@source, "\n")
             cat("  Dimension             :", paste(object@ddim, collapse="x"), "\n")
             ns0 <- length(object@s0ind)
             cat("  Number of S0 images   :", paste(ns0, collapse="x"), "\n")
